from __future__ import print_function, unicode_literals
import json
import mimetypes
import os
import urllib
from hashlib import sha256
from random import randint

import requests
import six

from .constants import (
    API_ENDPOINT,
    DEFAULT_CONFIG,
    DEFAULT_OBJECTS,
    REQUEST_HEADERS,
)
from .exceptions import APIError, ConfigError, HTTPError, ZenfolioError
from .utils import AttrDict, convert_from_datetime, convert_to_datetime
from .validate import assert_type, validate_object, validate_value


class PyZenfolio(object):
    def __init__(self, config_file=None, auth=None):
        self.config = AttrDict(DEFAULT_CONFIG)
        if config_file:
            self.config.update(self.get_config(config_file))
            self.auth = self.config.auth
        if auth:
            self.auth = AttrDict(auth)
        self.init_session()

    # ---------------------------------------------------------------#
    #                      Authentication                            #
    # ---------------------------------------------------------------#

    def Authenticate(self, force=False):
        if 'token' in self.auth and self.auth.token and not force:
            return

        _challenge = self.GetChallenge()
        salt = b''.join(map(six.int2byte, _challenge.PasswordSalt))
        challenge = b''.join(map(six.int2byte, _challenge.Challenge))

        password_hash = sha256(salt + self.auth.password.encode('utf-8')).digest()
        proof = sha256(challenge + password_hash).digest()
        proof_as_ints = list(six.iterbytes(proof))

        token = self.call('Authenticate', [_challenge.Challenge, proof_as_ints])
        self.auth.token = token
        return token

    def GetChallenge(self):
        return self.call('GetChallenge', self.auth.username)

    def AuthenticatePlain(self):
        token = self.call('AuthenticatePlain', [self.auth.username, self.auth.password])
        self.auth.token = token

    def AuthenticateVisitor(self):
        visitor_key = self.GetVisitorKey()
        token = self.call('AuthenticateVisitor', [visitor_key])
        self.auth.token = token

    def GetVisitorKey(self):
        return self.call('GetVisitorKey')

    # ---------------------------------------------------------------#
    #                        Get methods                             #
    # ---------------------------------------------------------------#

    def GetCategories(self):
        return self.call('GetCategories')

    def GetDownloadOriginalKey(self, photo_id, password):
        return self.call('GetDownloadOriginalKey', [photo_id, password])

    def GetPopularPhotos(self, offset=0, limit=1000):
        return self.call('GetPopularPhotos', [offset, limit])

    def GetPopularSets(self, set_type='Gallery', offset=0, limit=1000):
        validate_value(set_type, 'PhotoSetType', 'GetPopularSets')
        return self.call('GetPopularSets', [set_type, offset, limit])

    def GetRecentPhotos(self, offset=0, limit=1000):
        return self.call('GetRecentPhotos', [offset, limit])

    def GetRecentSets(self, set_type='Gallery', offset=0, limit=1000):
        validate_value(set_type, 'PhotoSetType', 'GetRecentSets')
        return self.call('GetRecentSets', [set_type, offset, limit])

    def GetVideoPlaybackUrl(self, photo_id, mode='Http', width=1920, height=1080):
        validate_value(mode, 'VideoPlaybackMode', 'GetVideoPlaybackUrl')
        return self.call('GetVideoPlaybackUrl', [photo_id, mode, width, height])

    # ---------------------------------------------------------------#
    #                        Load methods                            #
    # ---------------------------------------------------------------#

    def LoadAccessRealm(self, realm_id):
        return self.call('LoadAccessRealm', realm_id)

    def LoadGroup(self, id, info_level='Full', recursive=False):
        validate_value(info_level, 'InformationLevel', 'LoadGroup')
        return self.call('LoadGroup', [id, info_level, recursive])

    def LoadGroupHierarchy(self, username=None):
        if username is None:
            username = self.auth.username
        return self.call('LoadGroupHierarchy', username)

    def LoadMessages(self, mailbox_id, posted_since=None, include_deleted=False):
        posted_since = convert_from_datetime(posted_since)
        return self.call('LoadMessages', [mailbox_id, posted_since, include_deleted])

    def LoadSharedFavoritesSets(self):
        return self.call('LoadSharedFavoritesSets')

    def LoadPhoto(self, photo_id, info_level='Full'):
        validate_value(info_level, 'InformationLevel', 'LoadPhoto')
        return self.call('LoadPhoto', [photo_id, info_level])

    def LoadPhotoSet(self, set_id, info_level='Full', with_photos=True):
        validate_value(info_level, 'InformationLevel', 'LoadPhotoSet')
        return self.call('LoadPhotoSet', [set_id, info_level, with_photos])

    def LoadPhotoSetPhotos(self, set_id, start_index=0, limit=5000):
        return self.call('LoadPhotoSetPhotos', [set_id, start_index, limit])

    def LoadPrivateProfile(self):
        return self.call('LoadPrivateProfile')

    def LoadPublicProfile(self, username=None):
        if username is None:
            username = self.auth.username
        return self.call('LoadPublicProfile', username)

    # ---------------------------------------------------------------#
    #                       Create methods                           #
    # ---------------------------------------------------------------#

    def CreateFavoritesSet(self, name, username, ids):
        return self.call('CreateFavoritesSet', [name, username, ids])

    def CreateGroup(self, parent_id, group=None):
        if group is None:
            group = {}
        updater = dict(DEFAULT_OBJECTS['GroupUpdater'])
        updater.update(group)
        validate_object(group, 'GroupUpdater', 'CreateGroup')
        return self.call('CreateGroup', [parent_id, updater])

    def CreatePhotoFromUrl(self, photoset_id, url, cookies=None):
        if isinstance(cookies, dict):
            cookies = ';'.join(['='.join([urllib.quote_plus(i) for i in c])
                                for c in cookies.items()])
        return self.call('CreatePhotoFromUrl', [photoset_id, url, cookies])

    def CreatePhotoSet(self, group_id, set_type='Gallery', photoset=None):
        validate_value(set_type, 'PhotoSetType', 'CreatePhotoSet')
        if photoset is None:
            photoset = {}
        updater = dict(DEFAULT_OBJECTS['PhotoSetUpdater'])
        updater.update(photoset)
        validate_object(updater, 'PhotoSetUpdater', 'CreatePhotoSet')
        return self.call('CreatePhotoSet', [group_id, set_type, updater])

    def CreateVideoFromUrl(self, photoset_id, url, cookies=None):
        if isinstance(cookies, dict):
            cookies = ';'.join(['='.join([urllib.quote_plus(i) for i in c])
                                for c in cookies.items()])
        return self.call('CreateVideoFromUrl', [photoset_id, url, cookies])

    def UploadPhoto(self, photoset, path, filename=None):
        assert_type(photoset, 'PhotoSet', 'photoset', 'UploadPhoto')
        upload_url = photoset.UploadUrl

        with open(path, 'rb') as fid:
            data = fid.read()
            filename = filename or os.path.basename(path)

            headers = self.get_request_headers()
            headers.update({
                'Content-Type': mimetypes.guess_type(filename)[0],
            })
            params = {
                'filename': filename,
            }
            request = requests.post(upload_url,
                                    params=params,
                                    data=data,
                                    headers=headers)
            if request.status_code != 200:
                raise HTTPError(API_ENDPOINT,
                                request.status_code,
                                request.headers,
                                request.content)
            return request.text

        raise APIError('Could not upload photo')

    def AddMessage(self, mail_id, message):
        validate_object(message, 'MessageUpdater', 'AddMessage')
        return self.call('AddMessage', [mail_id, message])

    # ---------------------------------------------------------------#
    #                         Set  methods                           #
    # ---------------------------------------------------------------#

    def SetGroupTitlePhoto(self, group_id, photo_id):
        return self.call('SetGroupTitlePhoto', [group_id, photo_id])

    def SetPhotoSetFeaturedIndex(self, photoset_id, index):
        return self.call('SetPhotoSetFeaturedIndex', [photoset_id, index])

    def SetPhotoSetTitlePhoto(self, photoset_id, photo_id):
        return self.call('SetPhotoSetTitlePhoto', [photoset_id, photo_id])

    def SetRandomPhotoSetTitlePhoto(self, photoset_id):
        return self.call('SetRandomPhotoSetTitlePhoto', [photoset_id])

    # ---------------------------------------------------------------#
    #                        Update methods                          #
    # ---------------------------------------------------------------#

    def UpdateGroup(self, group_id, group=None):
        if group is None:
            group = {}
        updater = dict(DEFAULT_OBJECTS['GroupUpdater'])
        updater.update(group)
        validate_object(updater, 'GroupUpdater', 'UpdateGroup')
        return self.call('UpdateGroup', [group_id, updater])

    def UpdateGroupAccess(self, group_id, group_access=None):
        if group_access is None:
            group_access = {}
        updater = dict(DEFAULT_OBJECTS['AccessUpdater'])
        updater.update(group_access)
        validate_object(updater, 'AccessUpdater', 'UpdateGroupAccess')
        return self.call('UpdateGroupAccess', [group_id, updater])

    def UpdatePhoto(self, photo_id, photo=None):
        if photo is None:
            photo = {}
        updater = dict(DEFAULT_OBJECTS['PhotoUpdater'])
        updater.update(photo)
        validate_object(updater, 'PhotoUpdater', 'UpdatePhoto')
        return self.call('UpdatePhoto', [photo_id, updater])

    def UpdatePhotoAccess(self, photo_id, photo_access=None):
        if photo_access is None:
            photo_access = {}
        updater = dict(DEFAULT_OBJECTS['AccessUpdater'])
        updater.update(photo_access)
        validate_object(updater, 'AccessUpdater', 'UpdatePhotoAccess')
        return self.call('UpdatePhotoAccess', [photo_id, updater])

    def UpdatePhotoSet(self, photoset_id, photoset=None):
        if photoset is None:
            photoset = {}
        updater = dict(DEFAULT_OBJECTS['PhotoSetUpdater'])
        updater.update(photoset)
        validate_object(updater, 'PhotoSetUpdater', 'UpdatePhotoSet')
        return self.call('UpdatePhotoSet', [photoset_id, updater])

    def UpdatePhotoSetAccess(self, photoset_id, photoset_access=None):
        if photoset_access is None:
            photoset_access = {}
        updater = dict(DEFAULT_OBJECTS['AccessUpdater'])
        updater.update(photoset_access)
        validate_object(updater, 'AccessUpdater', 'UpdatePhotoSetAccess')
        return self.call('UpdatePhotoSetAccess', [photoset_id, updater])

    # ---------------------------------------------------------------#
    #                          Move methods                          #
    # ---------------------------------------------------------------#

    def MoveGroup(self, group_id, dest_group_id, index):
        return self.call('MoveGroup', [group_id, dest_group_id, index])

    def MovePhoto(self, photoset_id, photo_id, dest_photoset_id, index):
        return self.call('MovePhoto', [photoset_id, photo_id, dest_photoset_id, index])

    def MovePhotos(self, photoset_id, dest_photoset_id, ids):
        return self.call('MovePhotos', [photoset_id, dest_photoset_id, ids])

    def MovePhotoSet(self, photoset_id, dest_group_id, index):
        return self.call('MovePhotoSet', [photoset_id, dest_group_id, index])

    # ---------------------------------------------------------------#
    #                            Search                              #
    # ---------------------------------------------------------------#

    def SearchPhotoByCategory(self, search_id, sort, category, offset, limit):
        validate_value(sort, 'SortOrder', 'SearchPhotoByCategory')
        return self.call('SearchPhotoByCategory', [search_id, sort, category, offset, limit])

    def SearchPhotoByText(self, search_id, sort, query, offset, limit):
        validate_value(sort, 'SortOrder', 'SearchPhotoByText')
        return self.call('SearchPhotoByText', [search_id, sort, query, offset, limit])

    def SearchSetByCategory(self, search_id, photoset_type, sort, category, offset, limit):
        validate_value(photoset_type, 'PhotoSetType', 'SearchSetByCategory')
        validate_value(sort, 'SortOrder', 'SearchSetByCategory')
        return self.call('SearchSetByCategory', [search_id, photoset_type, sort, category, offset, limit])

    def SearchSetByText(self, search_id, photoset_type, sort, query, offset, limit):
        validate_value(photoset_type, 'PhotoSetType', 'SearchSetByText')
        validate_value(sort, 'SortOrder', 'SearchSetByText')
        return self.call('SearchSetByText', [search_id, photoset_type, sort, query, offset, limit])

    # ---------------------------------------------------------------#
    #                        Delete methods                          #
    # ---------------------------------------------------------------#

    def DeleteGroup(self, group_id):
        return self.call('DeleteGroup', group_id)

    def DeleteMessage(self, mailbox_id, index):
        return self.call('DeleteMessage', [mailbox_id, index])

    def DeletePhoto(self, photo_id):
        return self.call('DeletePhoto', photo_id)

    def DeletePhotos(self, photo_ids):
        return self.call('DeletePhotos', photo_ids)

    def DeletePhotoSet(self, photoset_id):
        return self.call('DeletePhotoSet', photoset_id)

    # ---------------------------------------------------------------#
    #                         Miscellaneous                          #
    # ---------------------------------------------------------------#

    def CollectionAddPhoto(self, coll_id, photo_id):
        return self.call('CollectionAddPhoto', [coll_id, photo_id])

    def CollectionRemovePhoto(self, coll_id, photo_id):
        return self.call('CollectionRemovePhoto', [coll_id, photo_id])

    def KeyringAddKeyPlain(self, keyring, realm_id, password):
        return self.call('KeyringAddKeyPlain', [keyring, realm_id, password])

    def KeyringGetUnlockedRealms(self, keyring):
        return self.call('KeyringGetUnlockedRealms', keyring)

    def ReindexPhotoSet(self, photoset_id, index, mapping):
        return self.call('ReindexPhotoSet', [photoset_id, index, mapping])

    def RemoveGroupTitlePhoto(self, group_id):
        return self.call('RemoveGroupTitlePhoto', [group_id])

    def RemovePhotoSetTitlePhoto(self, photoset_id):
        return self.call('RemovePhotoSetTitlePhoto', [photoset_id])

    def ReorderGroup(self, group_id, order):
        validate_value(order, 'GroupShiftOrder', 'ReorderGroup')
        return self.call('ReorderGroup', [group_id, order])

    def ReorderPhotoSet(self, photoset_id, order):
        validate_value(order, 'ShiftOrder', 'ReorderPhotoSet')
        return self.call('ReorderPhotoSet', [photoset_id, order])

    def ReplacePhoto(self, original_id, replacement_id):
        return self.call('ReplacePhoto', [original_id, replacement_id])

    def RotatePhoto(self, photo_id, rotation):
        validate_value(rotation, 'PhotoRotation', 'RotatePhoto')
        return self.call('RotatePhoto', [photo_id, rotation])

    def ShareFavoritesSet(self, favset_id, favset_name, name, email, message):
        return self.call('ShareFavoritesSet', [favset_id, favset_name, name, email, message])

    def UndeleteMessage(self, mailbox_id, message_index):
        return self.call('UndeleteMessage', [mailbox_id, message_index])

    # ---------------------------------------------------------------#
    #                           Internals                            #
    # ---------------------------------------------------------------#

    def get_config(self, config_file):
        with open(config_file, 'rb') as fid:
            data = fid.read().decode('utf-8')
            try:
                return AttrDict(json.loads(data))
            except ValueError:
                raise ConfigError('Could not open config file')

    def get_request_headers(self):
        headers = dict(REQUEST_HEADERS)
        if 'token' in self.auth:
            headers.update({
                'X-Zenfolio-Token': self.auth.token
            })
        return headers

    def init_session(self):
        self.session = requests.Session()

    def call(self, method, params=None):
        if params is None:
            params = []
        elif not isinstance(params, (list, tuple)):
            params = [params]

        data = AttrDict({
            'method': method,
            'params': params,
            'id': randint(0, 2 ** 16 - 1)
        })

        try:
            request = self.session.post(API_ENDPOINT,
                                        data=json.dumps(data),
                                        headers=self.get_request_headers())
        except Exception as e:
            raise APIError(e.message)
        if request.status_code != 200:
            raise HTTPError(API_ENDPOINT,
                            request.status_code,
                            request.headers,
                            request.content)

        body = convert_to_datetime(AttrDict(request.json()))

        if body.error:
            code = None
            if 'code' in body.error:
                code = body.error.code
            raise ZenfolioError(code, body.error.message)

        if body.id != data.id:
            raise APIError('Response ID does match request ID')

        return body.result



from __future__ import print_function, unicode_literals


__version__ = '0.9.1'
__author__ = 'Miroslav Shubernetskiy'

try:
    from .api import PyZenfolio  # noqa
    from .exceptions import APIError  # noqa
    from .helpers import search_sets_by_title  # noqa
except ImportError:
    pass



from __future__ import print_function, unicode_literals

from .exceptions import APIError


VALID_ENUM = {
    'AccessMask': [
        'None',
        'HideDateCreated',
        'HideDateModified',
        'HideDateTaken',
        'HideMetaData',
        'HideUserStats',
        'HideVisits',
        'NoCollections',
        'NoPrivateSearch',
        'NoPublicSearch',
        'NoRecentList',
        'ProtectExif',
        'ProtectXXLarge',
        'ProtectExtraLarge',
        'ProtectLarge',
        'ProtectMedium',
        'ProtectOriginals',
        'ProtectGuestbook',
        'NoPublicGuestbookPosts',
        'NoPrivateGuestbookPosts',
        'NoAnonymousGuestbookPosts',
        'ProtectComments',
        'NoPublicComments',
        'NoPrivateComments',
        'NoAnonymousComments',
        'PasswordProtectOriginals',
        'UnprotectCover',
        'ProtectAll',
    ],
    'AccessType': [
        'Private',
        'Public',
        'UserList',
        'Password',
    ],
    'InformationLevel': [
        'Level1',
        'Level2',
        'Full',
    ],
    'GroupShiftOrder': [
        'CreatedAsc',
        'CreatedDesc',
        'ModifiedAsc',
        'ModifiedDesc',
        'TitleAsc',
        'TitleDesc',
        'GroupsTop',
        'GroupsBottom',
    ],
    'PhotoSetType': [
        'Gallery',
        'Collection',
    ],
    'PhotoRotation': [
        'None',
        'Rotate90',
        'Rotate180',
        'Rotate270',
        'Flip',
        'Rotate90Flip',
        'Rotate180Flip',
        'Rotate270Flip',
    ],
    'ShiftOrder': [
        'CreatedAsc',
        'CreatedDesc',
        'TakenAsc',
        'TakenDesc',
        'TitleAsc',
        'TitleDesc',
        'SizeAsc',
        'SizeDesc',
        'FileNameAsc',
        'FileNameDesc',
    ],
    'SortOrder': [
        'Date',
        'Popularity',
        'Rank',
    ],
    'VideoPlaybackMode': [
        'Flash',
        'iOS',
        'Http',
    ],
}
VALID_OBJECTS = {
    'AccessUpdater': {
        'AccessMask': 'AccessMask',
        'AccessType': 'AccessType',
        'Viewers': None,
        'Password': None,
        'IsDerived': None,
        'PasswordHint': None,
    },
    'GroupUpdater': {
        'Title': None,
        'Caption': None,
        'CustomReference': None,
    },
    'PhotoSetUpdater': {
        'Title': None,
        'Caption': None,
        'Keywords': None,
        'Categories': None,
        'CustomReference': None,
    },
    'PhotoUpdater': {
        'Title': None,
        'Caption': None,
        'Keywords': None,
        'Categories': None,
        'Copyright': None,
        'Filename': None,
    },
    'MessageUpdater': {
        'PosterName': None,
        'PosterUrl': None,
        'PosterEmail': None,
        'Body': None,
        'IsPrivate': None,
    },
}


def assert_type(value, expected_type, param, method):
    if value['$type'] != expected_type:
        raise APIError('Got `{0}` instead of `{1}` value for `{2}` for `{3}` method.'
                       ''.format(value['$type'], expected_type, param, method))


def validate_value(value, data_struct, method):
    if value not in VALID_ENUM[data_struct]:
        raise APIError('`{0}` is an invalid value for `{1}` enumeration for `{2}` method.'
                       ''.format(value, data_struct, method))


def validate_object(value, data_struct, method):
    if not isinstance(value, dict):
        raise APIError('`{0}` must be a dict for `{1}` method.'
                       ''.format(data_struct, method))

    for k, v in value.items():
        if k not in VALID_OBJECTS[data_struct]:
            raise APIError('`{0}` is an invalid key for `{1}` object for `{2}` method.'
                           ''.format(value, data_struct, method))
        enum = VALID_OBJECTS[data_struct][k]
        if enum is not None:
            validate_value(v, enum, method)



from __future__ import print_function, unicode_literals


class Helper(object):
    pass


class SearchSetsByTitle(Helper):
    def search(self, title, elements):
        results = []
        for element in elements:
            if title.lower() in element.Title.lower():
                results.append(element)
            if 'Elements' in element:
                results += self.search(title, element.Elements)
        return results

    def __call__(self, api, title, username=None):
        hierarchy = api.LoadGroupHierarchy(username)
        return self.search(title, hierarchy.Elements)


search_sets_by_title = SearchSetsByTitle()



from __future__ import print_function, unicode_literals
from datetime import datetime

from .constants import DATETIME_FORMAT


class AttrDict(dict):
    def __init__(self, data):
        super(AttrDict, self).__init__(data)
        self.convert(self, self.items())
        self.__dict__ = self

    def convert(self, root, items):
        for k, v in items:
            if isinstance(v, dict):
                root[k] = AttrDict(v)
            elif isinstance(v, (list, tuple)):
                self.convert(v, enumerate(v))


class ConvertToDateTime(object):
    """
    Finds all DateTime instances and converts to datetime objects.
    """

    def find_and_convert_dates(self, root, items):
        for k, v in items:
            if isinstance(v, dict):
                if '$type' in v and v['$type'] == 'DateTime':
                    root[k] = datetime.strptime(v['Value'], DATETIME_FORMAT)
                else:
                    self.find_and_convert_dates(v, v.items())
            elif isinstance(v, (list, tuple)):
                self.find_and_convert_dates(v, enumerate(v))

    def __call__(self, data):
        self.find_and_convert_dates(data, data.items())
        return data


convert_to_datetime = ConvertToDateTime()


def convert_from_datetime(value):
    if isinstance(value, datetime):
        return AttrDict({
            '$type': 'DateTime',
            'Value': value.strftime(DATETIME_FORMAT)
        })
    return value



from __future__ import print_function, unicode_literals

import six


class APIError(Exception):
    pass


class ConfigError(APIError):
    pass


@six.python_2_unicode_compatible
class ZenfolioError(APIError):
    def __init__(self, code, message):
        self.code = code
        self.message = message

    def __str__(self):
        return '{} - {}'.format(self.code, self.message)


@six.python_2_unicode_compatible
class HTTPError(APIError):
    def __init__(self, url, status_code, headers, content):
        self.url = url
        self.status_code = status_code
        self.headers = headers
        self.content = content

    def __str__(self):
        return '{} - {}'.format(self.url, self.status_code)



from __future__ import unicode_literals, print_function
import os
from setuptools import setup
from pyzenfolio import __version__, __author__


def get_packages(package):
    return [str(dirpath)
            for dirpath, dirnames, filenames in os.walk(package)
            if os.path.exists(os.path.join(dirpath, '__init__.py'))]


def get_package_data(package):
    walk = [(dirpath.replace(package + os.sep, '', 1), filenames)
            for dirpath, dirnames, filenames in os.walk(package)
            if not os.path.exists(os.path.join(dirpath, '__init__.py'))]

    filepaths = []
    for base, filenames in walk:
        filepaths.extend([os.path.join(base, filename)
                          for filename in filenames])
    return {package: filepaths}


def read(fname):
    return open(fname, 'rb').read().decode('utf-8')


setup(
    name="pyzenfolio",
    version=__version__,
    author=__author__,
    author_email="miroslav@miki725.com",
    description=("Light-weight Zenfolio API Python wrapper."),
    long_description=read('README.rst') + read('LICENSE.rst'),
    license="MIT",
    keywords="zenfolio",
    url="https://github.com/miki725/pyzenfolio",
    packages=get_packages('pyzenfolio'),
    install_requires=[
        'requests',
        'six',
    ],
    classifiers=[
        "Development Status :: 3 - Alpha",
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        "Topic :: Utilities",
        "License :: OSI Approved :: MIT License",
        'Topic :: Internet :: WWW/HTTP',
        'Programming Language :: Python',
    ]
)



from __future__ import print_function, unicode_literals


API_VERSION = '1.7'
API_ENDPOINT_FORMAT = 'https://api.zenfolio.com/api/{0}/zfapi.asmx'
API_ENDPOINT = API_ENDPOINT_FORMAT.format(API_VERSION)
DEFAULT_CONFIG = {}
REQUEST_HEADERS = {
    'Content-Type': 'application/json',
}

DATETIME_FORMAT = '%Y-%m-%d %H:%M:%S'

PROFILE_RESOLUTIONS = {
    50: (120, 120),
    51: (80, 80),
}
PHOTO_RESOLUTIONS = {
    0: (80, 80),
    1: (60, 60),
    2: (400, 400),
    3: (580, 450),
    4: (800, 630),
    5: (1100, 850),
    6: (1550, 960),
    10: (120, 120),
    11: (120, 120),
}
VIDEO_RESOLUTIONS = {
    200: 1080,
    210: 720,
    215: 480,
    220: 360,
    250: None,
}

DEFAULT_OBJECTS = {
    'AccessUpdater': {
        'IsDerived': True,
    },
    'GroupUpdater': {
        'Title': '',
    },
    'PhotoSetUpdater': {
        'Title': '',
    },
    'PhotoUpdater': {
        'Title': '',
    },
    'MessageUpdater': {
        'PosterName': '',
        'PosterUrl': '',
        'PosterEmail': '',
        'Body': '',
        'IsPrivate': False,
    },
}
